@@ -1,7 +1,7 @@
 from __future__ import annotations
 from tuneflow_py.base_plugin import TuneflowPlugin
 from tuneflow_py.models.audio_plugin import AudioPlugin, get_audio_plugin_tuneflow_id, are_tuneflow_ids_equal, are_tuneflow_ids_equal_ignore_version, decode_audio_plugin_tuneflow_id
-from tuneflow_py.models.automation import AutomationTarget, AutomationTargetType
+from tuneflow_py.models.automation import AutomationTarget, AutomationTargetType, AutomationData, AutomationPoint, AutomationValue
 from tuneflow_py.models.clip import ClipType, Clip
 from tuneflow_py.models.note import Note
 from tuneflow_py.models.song import Song
@@ -15,4 +15,4 @@ from tuneflow_py.descriptors.common import *
 from tuneflow_py.descriptors.audio_plugin_descriptor import *
 from tuneflow_py.descriptors.clip_descriptor import *
 from tuneflow_py.descriptors.plugin import *
-from tuneflow_py.utils import *
\ No newline at end of file
+from tuneflow_py.utils import *
