@@ -1,40 +1,40 @@
-from typing_extensions import TypedDict
+from typing_extensions import TypedDict, Required, NotRequired
 
 
-class AudioPluginDescriptor(TypedDict, total=False):
+class AudioPluginDescriptor(TypedDict):
     '''
     Descriptor of an audio plugin.
     '''
 
-    category: str
+    category: NotRequired[str]
     '''
     Category of the plugin.
     e.g.: 'Instrument|Synth', 'Fx|EQ', etc.
     '''
 
-    descriptiveName: str
+    descriptiveName: NotRequired[str]
     ''' A more detailed name. '''
 
-    id: str
+    id: Required[str]
     ''' An internal id of the plugin. '''
 
-    isInstrument: str
+    isInstrument: Required[str]
     '''
     Whether this plugin can be used as an instrument to generate
     sound from MIDI notes.
     '''
 
-    manufacturerName: str
+    manufacturerName: Required[str]
     ''' Manufacturer of the plugin. '''
 
-    name: str
+    name: Required[str]
     '''
     A short name of the plugin.
     Use this when creating `AudioPlugin` instances.
     '''
 
-    pluginFormatName: str
+    pluginFormatName: Required[str]
     ''' Format of the plugin. e.g. 'VST3', 'AudioUnit', etc. '''
 
-    version: str
+    version: Required[str]
     ''' Version of the plugin. '''
